@@ -1,12 +1,16 @@
+from re import compile
 from abc import abstractmethod
 from typing import Dict, Optional
+from functools import cached_property
 
 
-class HttpContext(object):
+class Context(object):
     """
     Context for a single incoming HTTP request.
     """
 
+    TOKEN_PATTERN = compile(r'^Bearer:\s*(.+)$')
+
     @property
     @abstractmethod
     def headers(self) -> Dict[str, str]:
@@ -15,18 +19,12 @@ class HttpContext(object):
         """
         raise NotImplementedError
 
-    @property
-    @abstractmethod
+    @cached_property
     def token(self) -> Optional[str]:
         """
         Returns request Bearer token.
         """
-        raise NotImplementedError
-
-    @property
-    @abstractmethod
-    def subject(self) -> Optional[str]:
-        """
-        Returns request headers.
-        """
-        raise NotImplementedError
+        if 'Authorization' in self.headers:
+            matches = self.TOKEN_PATTERN.findall(self.headers['Authorization'])
+            if matches:
+                return matches[0]
